/******************************************************************************/
/*! @file table_utf8_gb18030.h
    @brief UTF-8/GB18030 table.
    @author Masashi Astro Tachibana, Apolloron Project.
 ******************************************************************************/

#ifndef _TABLE_UTF8_GB18030_H_
#define _TABLE_UTF8_GB18030_H_

namespace apolloron {

#define UTF8_GB18030_TABLE_MAX 8678

typedef struct {
    const char *utf8;
    const char *gb18030;
    unsigned char count;
} T_UTF8_GB18030;

extern const T_UTF8_GB18030 utf8_gb18030[UTF8_GB18030_TABLE_MAX];


} // namespace apolloron
#endif
